@@ -10,5 +10,5 @@ test_that("genotypes returns the correct dims for data.frame", {
 })
 
 test_that("genotypes returns the correct value", {
-	expect_that(genotypes('rs9939609', userid='1,6,8', df=TRUE)[2,4], equals("Nash Parovoz"))
+	expect_that(genotypes('rs9939609', userid='1,6,8', df=TRUE)[2,4], matches("Nash Parovoz"))
 })
\ No newline at end of file
